==> openshift-model-hive-6.7.2-sources.jar: io/fabric8/openshift/api/model/hive/aws/v1/PrivateLinkAccessStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.aws.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrivateLinkAccessStatusBuilder extends PrivateLinkAccessStatusFluentImpl<PrivateLinkAccessStatusBuilder> implements VisitableBuilder<PrivateLinkAccessStatus,PrivateLinkAccessStatusBuilder>{
  public PrivateLinkAccessStatusBuilder() {
    this(false);
  }
  public PrivateLinkAccessStatusBuilder(Boolean validationEnabled) {
    this(new PrivateLinkAccessStatus(), validationEnabled);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrivateLinkAccessStatus(), validationEnabled);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent,PrivateLinkAccessStatus instance) {
    this(fluent, instance, false);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent,PrivateLinkAccessStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHostedZoneID(instance.getHostedZoneID());
      fluent.withVpcEndpointID(instance.getVpcEndpointID());
      fluent.withVpcEndpointService(instance.getVpcEndpointService());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatus instance) {
    this(instance,false);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHostedZoneID(instance.getHostedZoneID());
      this.withVpcEndpointID(instance.getVpcEndpointID());
      this.withVpcEndpointService(instance.getVpcEndpointService());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrivateLinkAccessStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PrivateLinkAccessStatus build() {
    PrivateLinkAccessStatus buildable = new PrivateLinkAccessStatus(fluent.getHostedZoneID(),fluent.getVpcEndpointID(),fluent.getVpcEndpointService());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-hive-6.8.0-sources.jar: io/fabric8/openshift/api/model/hive/aws/v1/PrivateLinkAccessStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.aws.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class PrivateLinkAccessStatusBuilder extends PrivateLinkAccessStatusFluent<PrivateLinkAccessStatusBuilder> implements VisitableBuilder<PrivateLinkAccessStatus,PrivateLinkAccessStatusBuilder>{
  public PrivateLinkAccessStatusBuilder() {
    this(false);
  }
  public PrivateLinkAccessStatusBuilder(Boolean validationEnabled) {
    this(new PrivateLinkAccessStatus(), validationEnabled);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new PrivateLinkAccessStatus(), validationEnabled);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent,PrivateLinkAccessStatus instance) {
    this(fluent, instance, false);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatusFluent<?> fluent,PrivateLinkAccessStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new PrivateLinkAccessStatus());

    if (instance != null) {
      fluent.withHostedZoneID(instance.getHostedZoneID());
      fluent.withVpcEndpointID(instance.getVpcEndpointID());
      fluent.withVpcEndpointService(instance.getVpcEndpointService());
      fluent.withHostedZoneID(instance.getHostedZoneID());
      fluent.withVpcEndpointID(instance.getVpcEndpointID());
      fluent.withVpcEndpointService(instance.getVpcEndpointService());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatus instance) {
    this(instance,false);
  }
  public PrivateLinkAccessStatusBuilder(PrivateLinkAccessStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new PrivateLinkAccessStatus());

    if (instance != null) {
      this.withHostedZoneID(instance.getHostedZoneID());
      this.withVpcEndpointID(instance.getVpcEndpointID());
      this.withVpcEndpointService(instance.getVpcEndpointService());
      this.withHostedZoneID(instance.getHostedZoneID());
      this.withVpcEndpointID(instance.getVpcEndpointID());
      this.withVpcEndpointService(instance.getVpcEndpointService());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  PrivateLinkAccessStatusFluent<?> fluent;
  Boolean validationEnabled;
  public PrivateLinkAccessStatus build() {
    PrivateLinkAccessStatus buildable = new PrivateLinkAccessStatus(fluent.getHostedZoneID(),fluent.getVpcEndpointID(),fluent.buildVpcEndpointService());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
